==> central-repository-3.61.0.zip: java/security/cert/Certificate.java <==
/*
 * Copyright (c) 1997, 2013, Oracle and/or its affiliates. All rights reserved.
 * Copyright 2015-2022 MicroEJ Corp. This file has been modified and/or created by MicroEJ Corp.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation. The Copyright holder(s) designates
 * this particular file as subject to the "Classpath" exception as provided
 * by the Copyright holder(s) in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact the Copyright holder(s) if you need additional information
 * or have any questions.
 * (if Oracle: 500 Oracle Parkway, Redwood Shores, CA 94065 USA or visit www.oracle.com)
 */

package java.security.cert;

import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PublicKey;
import java.security.SignatureException;

import ej.annotation.Nullable;

/**
 * <p>
 * Abstract class for managing a variety of identity certificates. An identity certificate is a binding of a principal
 * to a public key which is vouched for by another principal. (A principal represents an entity such as an individual
 * user, a group, or a corporation.)
 * <p>
 * This class is an abstraction for certificates that have different formats but important common uses. For example,
 * different types of certificates, such as X.509 and PGP, share general certificate functionality (like encoding and
 * verifying) and some types of information (like a public key).
 * <p>
 * X.509, PGP, and SDSI certificates can all be implemented by subclassing the Certificate class, even though they
 * contain different sets of information, and they store and retrieve the information in different ways.
 *
 * @see X509Certificate
 * @see CertificateFactory
 *
 * @author Hemma Prafullchandra
 */

public abstract class Certificate implements java.io.Serializable {

	private static final long serialVersionUID = -3585440601605666277L;

	/**
	 * Creates a certificate of the specified type.
	 *
	 * @param type
	 *            the standard name of the certificate type. See the CertificateFactory Types section in the <a href=
	 *            "https://docs.oracle.com/en/java/javase/19/docs/specs/security/standard-names.html#certificatefactory-types">
	 *            Java Security Standard Algorithm Names Specification</a> for information about standard certificate
	 *            types. Consult the release documentation for your implementation to see which types are supported.
	 */
	protected Certificate(String type) {
		throw new RuntimeException();
	}

	/**
	 * Returns the type of this certificate.
	 *
	 * @return the type of this certificate.
	 */
	public final String getType() {
		throw new RuntimeException();
	}

	/**
	 * Compares this certificate for equality with the specified object. If the {@code other} object is an
	 * {@code instanceof} {@code Certificate}, then its encoded form is retrieved and compared with the encoded form of
	 * this certificate.
	 *
	 * @param other
	 *            the object to test for equality with this certificate.
	 * @return true iff the encoded forms of the two certificates match, false otherwise.
	 */
	@Override
	public boolean equals(@Nullable Object other) {
		throw new RuntimeException();
	}

	/**
	 * Returns a hashcode value for this certificate from its encoded form.
	 *
	 * @return the hashcode value.
	 */
	@Override
	public int hashCode() {
		throw new RuntimeException();
	}

	/**
	 * Returns the encoded form of this certificate. It is assumed that each certificate type would have only a single
	 * form of encoding; for example, X.509 certificates would be encoded as ASN.1 DER.
	 *
	 * @return the encoded form of this certificate
	 *
	 * @exception CertificateEncodingException
	 *                if an encoding error occurs.
	 */
	public abstract byte[] getEncoded() throws CertificateEncodingException;

	/**
	 * Verifies that this certificate was signed using the private key that corresponds to the specified public key.
	 *
	 * @param key
	 *            the PublicKey used to carry out the verification.
	 *
	 * @exception NoSuchAlgorithmException
	 *                on unsupported signature algorithms.
	 * @exception InvalidKeyException
	 *                on incorrect key.
	 * @exception NoSuchProviderException
	 *                if there's no default provider.
	 * @exception SignatureException
	 *                on signature errors.
	 * @exception CertificateException
	 *                on encoding errors.
	 */
	public abstract void verify(PublicKey key) throws CertificateException, NoSuchAlgorithmException,
			InvalidKeyException, NoSuchProviderException, SignatureException;

	/**
	 * Verifies that this certificate was signed using the private key that corresponds to the specified public key.
	 * This method uses the signature verification engine supplied by the specified provider.
	 *
	 * @param key
	 *            the PublicKey used to carry out the verification.
	 * @param sigProvider
	 *            the name of the signature provider.
	 *
	 * @exception NoSuchAlgorithmException
	 *                on unsupported signature algorithms.
	 * @exception InvalidKeyException
	 *                on incorrect key.
	 * @exception NoSuchProviderException
	 *                on incorrect provider.
	 * @exception SignatureException
	 *                on signature errors.
	 * @exception CertificateException
	 *                on encoding errors.
	 */
	public abstract void verify(PublicKey key, String sigProvider) throws CertificateException,
			NoSuchAlgorithmException, InvalidKeyException, NoSuchProviderException, SignatureException;

	/**
	 * Returns a string representation of this certificate.
	 *
	 * @return a string representation of this certificate.
	 */
	@Override
	public abstract String toString();

	/**
	 * Gets the public key from this certificate.
	 *
	 * @return the public key.
	 */
	public abstract PublicKey getPublicKey();
}

==> central-repository-3.63.0.zip: java/security/cert/Certificate.java <==
/*
 * Copyright (c) 1997, 2013, Oracle and/or its affiliates. All rights reserved.
 * Copyright 2015-2022 MicroEJ Corp. This file has been modified by MicroEJ Corp.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */

package java.security.cert;

import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PublicKey;
import java.security.SignatureException;

import ej.annotation.Nullable;

/**
 * <p>
 * Abstract class for managing a variety of identity certificates. An identity certificate is a binding of a principal
 * to a public key which is vouched for by another principal. (A principal represents an entity such as an individual
 * user, a group, or a corporation.)
 * <p>
 * This class is an abstraction for certificates that have different formats but important common uses. For example,
 * different types of certificates, such as X.509 and PGP, share general certificate functionality (like encoding and
 * verifying) and some types of information (like a public key).
 * <p>
 * X.509, PGP, and SDSI certificates can all be implemented by subclassing the Certificate class, even though they
 * contain different sets of information, and they store and retrieve the information in different ways.
 *
 * @see X509Certificate
 * @see CertificateFactory
 *
 * @author Hemma Prafullchandra
 */

public abstract class Certificate implements java.io.Serializable {

	private static final long serialVersionUID = -3585440601605666277L;

	/**
	 * Creates a certificate of the specified type.
	 *
	 * @param type
	 *            the standard name of the certificate type. See the CertificateFactory section in the
	 *            <a href= "{@docRoot}/../technotes/guides/security/StandardNames.html#CertificateFactory"> Java
	 *            Cryptography Architecture Standard Algorithm Name Documentation</a> for information about standard
	 *            certificate types.
	 */
	protected Certificate(String type) {
		throw new RuntimeException();
	}

	/**
	 * Returns the type of this certificate.
	 *
	 * @return the type of this certificate.
	 */
	public final String getType() {
		throw new RuntimeException();
	}

	/**
	 * Compares this certificate for equality with the specified object. If the {@code other} object is an
	 * {@code instanceof} {@code Certificate}, then its encoded form is retrieved and compared with the encoded form of
	 * this certificate.
	 *
	 * @param other
	 *            the object to test for equality with this certificate.
	 * @return true iff the encoded forms of the two certificates match, false otherwise.
	 */
	@Override
	public boolean equals(@Nullable Object other) {
		throw new RuntimeException();
	}

	/**
	 * Returns a hashcode value for this certificate from its encoded form.
	 *
	 * @return the hashcode value.
	 */
	@Override
	public int hashCode() {
		throw new RuntimeException();
	}

	/**
	 * Returns the encoded form of this certificate. It is assumed that each certificate type would have only a single
	 * form of encoding; for example, X.509 certificates would be encoded as ASN.1 DER.
	 *
	 * @return the encoded form of this certificate
	 *
	 * @exception CertificateEncodingException
	 *                if an encoding error occurs.
	 */
	public abstract byte[] getEncoded() throws CertificateEncodingException;

	/**
	 * Verifies that this certificate was signed using the private key that corresponds to the specified public key.
	 *
	 * @param key
	 *            the PublicKey used to carry out the verification.
	 *
	 * @exception NoSuchAlgorithmException
	 *                on unsupported signature algorithms.
	 * @exception InvalidKeyException
	 *                on incorrect key.
	 * @exception NoSuchProviderException
	 *                if there's no default provider.
	 * @exception SignatureException
	 *                on signature errors.
	 * @exception CertificateException
	 *                on encoding errors.
	 */
	public abstract void verify(PublicKey key) throws CertificateException, NoSuchAlgorithmException,
			InvalidKeyException, NoSuchProviderException, SignatureException;

	/**
	 * Verifies that this certificate was signed using the private key that corresponds to the specified public key.
	 * This method uses the signature verification engine supplied by the specified provider.
	 *
	 * @param key
	 *            the PublicKey used to carry out the verification.
	 * @param sigProvider
	 *            the name of the signature provider.
	 *
	 * @exception NoSuchAlgorithmException
	 *                on unsupported signature algorithms.
	 * @exception InvalidKeyException
	 *                on incorrect key.
	 * @exception NoSuchProviderException
	 *                on incorrect provider.
	 * @exception SignatureException
	 *                on signature errors.
	 * @exception CertificateException
	 *                on encoding errors.
	 */
	public abstract void verify(PublicKey key, String sigProvider) throws CertificateException,
			NoSuchAlgorithmException, InvalidKeyException, NoSuchProviderException, SignatureException;

	/**
	 * Returns a string representation of this certificate.
	 *
	 * @return a string representation of this certificate.
	 */
	@Override
	public abstract String toString();

	/**
	 * Gets the public key from this certificate.
	 *
	 * @return the public key.
	 */
	public abstract PublicKey getPublicKey();
}
